Authors
=======

django-cal was originally created in early 2011 at States of Pop.

The **PRIMARY AUTHORS** are (and/or have been):

  - Maik Hoepfel <m@maikhoepfel.de>

We're grateful to those **CONTRIBUTORS**:

  - Gabriel Grant <g@briel.ca>
  - Tuk Bredsdorff
  - Alexander Yakovlev <ayakovlev@rambler.ru>

Please feel free to add yourself to this list when you have contributed. 
A list of all contributors can be found [at Github](https://github.com/statesofpop/django-cal/graphs/contributors).
